@@ -35,7 +35,12 @@ def set_backend_kwarg(fn):
         return fn(*args, **kwargs)
     return inner
 
-def cast_num_dimensions(dim_len = 3):
+def expand_dims_to(t, len = 3):
+    if len == 0:
+        return t
+    return t.reshape(*((1,) * len), *t.shape) # will work with both torch and numpy
+
+def expand_arg_dims(dim_len = 3):
     """ pack here for reuse. 
         turns input into (B x D x N)
     """
@@ -44,8 +49,8 @@ def cast_num_dimensions(dim_len = 3):
         def inner(x, y, **kwargs):
             assert len(x.shape) == len(y.shape), "Shapes of A and B must match."
             remaining_len = len(x.shape) - dim_len
-            x = x.reshape(*((1,) * remaining_len), *x.shape) # will work with both torch and numpy
-            y = y.reshape(*((1,) * remaining_len), *y.shape)
+            x = expand_dims_to(x, remaining_len)
+            y = expand_dims_to(y, remaining_len)
             return fn(x, y, **kwargs)
         return inner
     return outer
@@ -54,7 +59,6 @@ def invoke_torch_or_numpy(torch_fn, numpy_fn):
     def outer(fn):
         @wraps(fn)
         def inner(*args, **kwargs):
-            print('getting')
             backend = kwargs.pop('backend')
             passed_args, passed_kwargs = fn(*args, **kwargs)
             backend_fn = torch_fn if backend == 'torch' else numpy_fn
@@ -266,9 +270,10 @@ def mds_torch(pre_dist_mat, weights=None, iters=10, tol=1e-5, verbose=2):
 
     if weights is None:
         weights = torch.ones_like(pre_dist_mat)
+
     # batched MDS
-    if len(pre_dist_mat.shape) < 3:
-        pre_dist_mat.unsqueeze_(0)
+    pre_dist_mat = expand_dims_to(pre_dist_mat, len = (len(pre_dist_mat) - 3))
+
     # start
     batch, N, _ = pre_dist_mat.shape
     his = []
@@ -587,7 +592,7 @@ def MDScaling(pre_dist_mat, **kwargs):
     """
     return pre_dist_mat, kwargs
 
-@cast_num_dimensions(dim_len = 2)
+@expand_arg_dims(dim_len = 2)
 @set_backend_kwarg
 @invoke_torch_or_numpy(kabsch_torch, kabsch_numpy)
 def Kabsch(A, B):
@@ -602,7 +607,7 @@ def Kabsch(A, B):
     # run calcs - pick the 0th bc an additional dim was created
     return A, B
 
-@cast_num_dimensions()
+@expand_arg_dims()
 @set_backend_kwarg
 @invoke_torch_or_numpy(rmsd_torch, rmsd_numpy)
 def RMSD(A, B):
@@ -616,7 +621,7 @@ def RMSD(A, B):
     """
     return A, B
 
-@cast_num_dimensions()
+@expand_arg_dims()
 @set_backend_kwarg
 @invoke_torch_or_numpy(gdt_torch, gdt_numpy)
 def GDT(A, B, *, mode="TS", cutoffs=[1,2,4,8], weights=None):
@@ -635,7 +640,7 @@ def GDT(A, B, *, mode="TS", cutoffs=[1,2,4,8], weights=None):
     # calculate GDT
     return (A, B, cutoffs), {'weights': weights}
 
-@cast_num_dimensions()
+@expand_arg_dims()
 @set_backend_kwarg
 @invoke_torch_or_numpy(tmscore_torch, tmscore_numpy)
 def TMscore(A, B):
